BODY {
	FONT-SIZE: 9pt; FONT-FAMILY: MS Sans Serif; background-color: #D6D3CE
}
TD, TH {
	FONT-SIZE: 9pt; FONT-FAMILY: MS Sans Serif
}
.bgr0 {
	FONT-SIZE: 9pt; FONT-FAMILY: MS Sans Serif; background-color: #ffffff
}
.bgr1 {
	FONT-SIZE: 9pt; FONT-FAMILY: MS Sans Serif; background-color: #485F70 /*#596084*/ /*#5f7452*/
}
.bgr2 {
	FONT-SIZE: 9pt; FONT-FAMILY: MS Sans Serif; background-color: #293869
}
.bgr3 {
	FONT-SIZE: 9pt; FONT-FAMILY: MS Sans Serif; background-color: #aab3d1
}
.bgr4 {
	FONT-SIZE: 9pt; FONT-FAMILY: MS Sans Serif; background-color: #efefef
}
.bgr5 {
	FONT-SIZE: 9pt; FONT-FAMILY: MS Sans Serif; background-color: #dededc
}
.bgr6 {
	FONT-SIZE: 9pt; FONT-FAMILY: MS Sans Serif; background-color: #888888
}
.bgr7 {
	FONT-SIZE: 9pt; FONT-FAMILY: MS Sans Serif; background-color: #b0b0b0
}
.bgr8 {
	FONT-SIZE: 9pt; FONT-FAMILY: MS Sans Serif; background-color: #D6D3CE
}
.bgr9 {
	FONT-SIZE: 9pt; FONT-FAMILY: MS Sans Serif; background-color: #dde5ef
}
.bgr13 {
	FONT-SIZE: 9pt; FONT-FAMILY: MS Sans Serif; background-color: #ffe0e0
}
.bgr10 {
	background-color: #424142
}




.outter {
	BORDER-RIGHT: #ffffff 1px solid; BORDER-TOP: #2d2d2d 1px solid; BORDER-LEFT: #2d2d2d 1px solid; BORDER-BOTTOM: #ffffff 1px solid; HEIGHT: 100%
}
.serv {
	BORDER-RIGHT: #2d2d2d 1px solid; BORDER-TOP: #ffffff 1px solid; BORDER-LEFT: #ffffff 1px solid; BORDER-BOTTOM: #2d2d2d 1px solid; background-color: #d0cfcf
}
.inner {
	BORDER-RIGHT: #ffffff 1px solid; BORDER-TOP: #2d2d2d 1px solid; BORDER-LEFT: #2d2d2d 1px solid; WIDTH: 100%; BORDER-BOTTOM: #ffffff 1px solid; HEIGHT: 100%
}
.color0 {
	FONT-SIZE: 9pt; COLOR: #ffffff; FONT-FAMILY: MS Sans Serif
}
.color1 {
	FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif
}
.color2 {
	FONT-SIZE: 9pt; COLOR: #5e5e5e; FONT-FAMILY: MS Sans Serif
}
.color3 {
	FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif
}
.color4 {
	FONT-SIZE: 9pt; COLOR: #ab300f; FONT-FAMILY: MS Sans Serif
}
.header0 {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #ffffff; FONT-FAMILY: MS Sans Serif; background-color: #5f7452
}
.header1 {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #ffffff; FONT-FAMILY: MS Sans Serif; background-color: #293869
}
.header2 {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #ffffff; FONT-FAMILY: MS Sans Serif; background-color: #888888
}
.header3 {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #ffffff; FONT-FAMILY: MS Sans Serif; background-color: #b0b0b0
}
.header4 {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; background-color: #ffffff
}
.header5 {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; background-color: #efefef
}
.header6 {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; background-color: #dededc
}
.header7 {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; background-color: #ffffff
}
.header8 {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; background-color: #efefef
}
.header9 {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; background-color: #dededc
}
.header10 {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #ab300f; FONT-FAMILY: MS Sans Serif; background-color: #ffffff
}
.header11 {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #ab300f; FONT-FAMILY: MS Sans Serif; background-color: #efefef
}
.header12 {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #ab300f; FONT-FAMILY: MS Sans Serif; background-color: #dededc
}
.header13 {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #ab300f; FONT-FAMILY: MS Sans Serif; background-color: #888888
}
.header14 {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #ab300f; FONT-FAMILY: MS Sans Serif; background-color: #b0b0b0
}
.header15 {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #ffffff; FONT-FAMILY: MS Sans Serif; background-color: #8e8e8e
}
.txt0 {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #ffffff; FONT-FAMILY: MS Sans Serif; background-color: #5f7452
}
.txt1 {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #ffffff; FONT-FAMILY: MS Sans Serif; background-color: #293869
}
.txt2 {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #ffffff; FONT-FAMILY: MS Sans Serif; background-color: #888888
}
.txt3 {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #ffffff; FONT-FAMILY: MS Sans Serif; background-color: #b0b0b0
}
.txt4 {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; background-color: #ffffff
}
.txt5 {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; background-color: #efefef
}
.txt6 {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; background-color: #dededc
}
.txt7 {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; background-color: #ffffff
}
.txt8 {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; background-color: #efefef
}
.txt9 {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; background-color: #dededc
}
.txt10 {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #c8c8c8; FONT-FAMILY: MS Sans Serif; background-color: #ffffff
}
.txt11 {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; background-color: #ffffff
}
.txt12 {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #ab300f; FONT-FAMILY: MS Sans Serif; background-color: #efefef
}
.txt13 {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #ab300f; FONT-FAMILY: MS Sans Serif; background-color: #ffffff
}
A {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #b0b0b0; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A:link {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #b0b0b0; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A:active {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #b0b0b0; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A:hover {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #b0b0b0; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A:visited {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #b0b0b0; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}

A.lnk0 {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk0:link {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk0:active {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk0:hover {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk0:visited {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}

A.lnk1 {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #596084; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk1:link {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #596084; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk1:active {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #596084; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk1:hover {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #596084; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk1:visited {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #596084; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}

A.lnk2 {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #ffffff; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk2:link {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #ffffff; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk2:active {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #ffffff; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk2:hover {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #ffffff; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk2:visited {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #ffffff; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk3 {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #ffffff; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk3:link {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #ffffff; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk3:active {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #ffffff; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk3:hover {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #ffffff; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk3:visited {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #ffffff; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk4 {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk4:link {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk4:active {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk4:hover {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk4:visited {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk5 {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk5:link {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk5:active {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk5:hover {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk5:visited {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk6 {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk6:link {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk6:active {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk6:hover {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk6:visited {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk7 {
	FONT-WEIGHT: normal; FONT-SIZE: 10px; COLOR: #293869; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk7:link {
	FONT-WEIGHT: normal; FONT-SIZE: 10px; COLOR: #293869; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk7:active {
	FONT-WEIGHT: normal; FONT-SIZE: 10px; COLOR: #293869; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk7:visited {
	FONT-WEIGHT: normal; FONT-SIZE: 10px; COLOR: #5e5e5e; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk7:hover {
	FONT-WEIGHT: normal; FONT-SIZE: 10px; COLOR: #5e5e5e; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk8 {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #ab300f; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk8:link {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #ab300f; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk8:active {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #ab300f; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk8:hover {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #ab300f; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk8:visited {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #ab300f; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk9 {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #ab300f; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk9:link {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #ab300f; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk9:active {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #ab300f; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk9:hover {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #ab300f; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk9:visited {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #ab300f; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk10 {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk10:link {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk10:active {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk10:hover {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk10:visited {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk11 {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk11:link {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk11:active {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk11:hover {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk11:active {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk11:visited {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #909090; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk12 {
	FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk12:link {
	FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk12:active {
	FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk12:hover {
	FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk12:visited {
	FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk13 {
	FONT-WEIGHT: normal; FONT-SIZE: 10px; COLOR: #ff0000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk13:link {
	FONT-WEIGHT: normal; FONT-SIZE: 10px; COLOR: #ff0000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk13:active {
	FONT-WEIGHT: normal; FONT-SIZE: 10px; COLOR: #ff0000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk13:hover {
	FONT-WEIGHT: normal; FONT-SIZE: 10px; COLOR: #ff0000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk13:active {
	FONT-WEIGHT: normal; FONT-SIZE: 10px; COLOR: #ff0000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk13:visited {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #ffffff; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk14 {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #415d8c; FONT-STYLE: italic; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk14:link {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #415d8c; FONT-STYLE: italic; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk14:active {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #415d8c; FONT-STYLE: italic; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk14:hover {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #415d8c; FONT-STYLE: italic; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk14:visited {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #415d8c; FONT-STYLE: italic; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk15 {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #909090; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk15:link {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #909090; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk15:active {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #909090; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk15:hover {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #909090; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk15:visited {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #909090; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk16 {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #909090; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk16:link {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #909090; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk16:active {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #909090; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk16:hover {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #909090; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk16:visited {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #909090; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}

A.lnk17 {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk17:link {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk17:active {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk17:hover {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk17:visited {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}

A.lnk18 {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none; font-style: italic
}
A.lnk18:link {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none; font-style: italic
}
A.lnk18:active {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none; font-style: italic
}
A.lnk18:hover {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none; font-style: italic
}
A.lnk18:visited {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none; font-style: italic
}

INPUT {
	FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif
}
SELECT {
	FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif
}
OPTION {
	FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif
}
TEXTAREA {
	FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif
}







.row-cell {
	FONT-FAMILY: Arial; 
	FONT-WEIGHT: normal; 
	FONT-SIZE: 10pt; 
	COLOR: #000000; 
	background-color: #ffffff;
	padding-top: 3px;
	padding-bottom: 2px;
}
.row-cell-transparent {
	FONT-FAMILY: Arial; 
	FONT-WEIGHT: normal; 
	FONT-SIZE: 10pt; 
	COLOR: #000000; 
	padding-top: 3px;
	padding-bottom: 2px;
}
.row-button {
	FONT-FAMILY: Arial; 
	FONT-WEIGHT: normal; 
	FONT-SIZE: 10pt; 
	COLOR: #000000; 
	background-color: #efefef;
	padding-top: 3px;
	padding-bottom: 2px;
}
.row-cell-total {
	FONT-FAMILY: Arial; 
	FONT-WEIGHT: bold;   
	FONT-SIZE: 10pt; 
	COLOR: #000000; 
	background-color: #efefef;
	padding-top: 5px;
	padding-bottom: 5px;
}
.row-cell-header {
	FONT-FAMILY: Arial; 
	FONT-WEIGHT: bold;   
	FONT-SIZE: 10pt; 
	COLOR: #000000; 
	background-color: #efefef;
	padding-top: 3px;
	padding-bottom: 2px;
	
/*
	border-top:solid 1px #D6D3CE;
	border-bottom:solid 1px #D6D3CE;
*/

	position: relative;
	top: expression(this.parentElement.parentElement.parentElement.parentElement.scrollTop);

}


/*
.row-cell-hilite {
	FONT-FAMILY: Arial; 
	FONT-SIZE: 10pt; 
	COLOR: #000000; 
	background-color: #dededc;
	padding-top: 3px;
	padding-bottom: 2px;
}
*/

.row-cell-hilite {
	background-color: #dededc;
}


A.row-cell, A.row-cell:link, A.row-cell:active, A.row-cell:hover, A.row-cell:visited {
	FONT-FAMILY: Arial; 
	FONT-SIZE: 10pt; 
	COLOR: #293869; 
	TEXT-DECORATION: none;
	background-color: transparent;
}
A.row-button, A.row-button:link, A.row-button:active, A.row-button:hover, A.row-button:visited {
	FONT-FAMILY: Arial; 
	FONT-SIZE: 10pt; 
	COLOR: #000000; 
	TEXT-DECORATION: none;
	background-color: transparent;
}
checkbox.row-cell,
	padding: 1px;
	background-color: transparent;
}



td.vert-menu {
	background-color: #D6D3CE;
	font-weight: normal; 
	font-size: 8pt; 
	color: black; 
	font-family: MS Sans Serif; 
	text-decoration: none;
	padding-top:4px;
	padding-bottom:4px;
}

td.main-menu {
	background-color: #D6D3CE;
	padding-top:1px;
	padding-bottom:1px;
	border-width:1px;
	border-style:solid;
	border-color:#D6D3CE;
}
a.main-menu, a.main-menu:link, a.main-menu:active, a.main-menu:visited, a.main-menu:hover {
	font-family: MS Sans Serif; 
	font-size: 8pt; 
	color: #000000; 
	text-decoration: none;
}


td.button {
	background-color: #D6D3CE;
	padding-top:0px;
	padding-bottom:0px;
	padding-left:3px;
	padding-right:3px;
	border-width:1px;
	border-style:solid;
	border-color:#D6D3CE;
}
A.button, A.button:link, A.button:active, A.button:hover, A.button:visited {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}





td.tabs-0 {
	background-color: #D6D3CE;
	padding-top:0px;
	padding-bottom:0px;
}
td.tabs-1 {
	background-color: #FFFFFF;
	padding-top:0px;
	padding-bottom:0px;
}
a.tabs, a.tabs:link, a.tabs:active, a.tabs:visited, a.tabs:hover {
	font-family: MS Sans Serif; 
	font-size: 8pt; 
	color: #000000; 
	text-decoration: none;
}

A.path, A.path:link, A.path:active, A.path:hover, A.path:visited {
	FONT-WEIGHT: normal; 
	FONT-SIZE: 8pt; 
/*	
	COLOR: #000000; 
*/	
	COLOR: #596084; 
	FONT-FAMILY: MS Sans Serif; 
	TEXT-DECORATION: none;
}





























.form-passive-label {
	FONT-WEIGHT: bold; 
	FONT-SIZE: 10pt; 
	FONT-FAMILY: Arial; 
	COLOR: #000000; 
	background-color: #fafaff;
	padding-left: 10px;
	padding-right: 10px;
	padding-top: 5px;
	padding-bottom: 5px;
}
.form-passive-inputs {
	FONT-SIZE: 10pt; 
	FONT-FAMILY: Arial; 
	background-color: #fafaff;
	padding-left: 5px;
	padding-right: 10px;
}
A.form-passive-inputs, A.form-passive-inputs:link, A.form-passive-inputs:hover, A.form-passive-inputs:visited {
	FONT-WEIGHT: normal; 
	FONT-SIZE: 10pt; 
	FONT-FAMILY: Arial; 
	COLOR: #293869; 
	TEXT-DECORATION: none;
	padding-left: 0px;
	padding-right: 0px;
}


.form-active-label {
	FONT-WEIGHT: bold; 
	FONT-SIZE: 10pt; 
	FONT-FAMILY: Arial; 
	COLOR: #000000; 
	background-color: #efefef;
	padding-left: 10px;
	padding-right: 10px;
	padding-top: 5px;
	padding-bottom: 5px;
}
.form-active-inputs {
	FONT-SIZE: 10pt; 
	FONT-FAMILY: Arial; 
	background-color: #efefef;
	padding-left: 5px;
	padding-right: 10px;
}

A.form-active-inputs, A.form-active-inputs:link, A.form-active-inputs:hover, A.form-active-inputs:visited {
	FONT-WEIGHT: normal; 
	FONT-SIZE: 10pt; 
	FONT-FAMILY: Arial; 
	COLOR: #293869; 
	TEXT-DECORATION: none;
	padding-left: 0px;
	padding-right: 0px;
}

.form-active-ellipsis {
	FONT-SIZE: 9pt; 
	FONT-FAMILY: Arial; 
	background-color: #ffffff;
}

input.form-active-inputs, select.form-active-inputs, textarea.form-active-inputs {
	FONT-SIZE: 10pt; 
	FONT-FAMILY: Arial; 
	background-color: #ffffff;
	border-color: #dededc;
	padding-left: 1px;
}




div.table-container {

      	PADDING-RIGHT: 0px;
      	OVERFLOW-Y: auto;
      	PADDING-LEFT: 0px;
      	OVERFLOW-X: auto;
      	PADDING-BOTTOM: 0px;
      	MARGIN: 0px;
      	WIDTH: expression(document.body.offsetWidth - (window.name == 'application_frame' ? 12 : 17));
      	PADDING-TOP: 0px;      	
      	
	scrollbar-base-color:#d6d3ce;
	scrollbar-arrow-color:#485f70;
	scrollbar-3dlight-color: #efefef;
	scrollbar-darkshadow-color:#b0b0b0;

}

div.checkboxes {

      	OVERFLOW: auto;
      	
	scrollbar-base-color:#d6d3ce;
	scrollbar-arrow-color:#485f70;
	scrollbar-3dlight-color: #efefef;
	scrollbar-darkshadow-color:#b0b0b0;

}
